@@ -25,7 +25,7 @@ def reset(controller):
     version(controller)
 
 
-def write_file(controller, filename, raw=False):
+def write_file(controller, filename):
     first_timestamp = None
     with open(filename, "r") as output_file:
         corrupt_entries = 0
@@ -52,42 +52,35 @@ def write_file(controller, filename, raw=False):
                     time.sleep(max(.0002, target_time - time.time()))
 
                 message_count += 1
-                controller.write(raw=raw, **parsed_message)
+                controller.write(**parsed_message)
         print("%d lines sent" % message_count)
         if corrupt_entries > 0:
             print("%d invalid lines in the data file were not sent" %
                     corrupt_entries)
 
 
-def write(controller, name, value, event=None, raw=False):
-    print("Sending command %s: %s %s" % (name, value, event))
-    if raw:
-        method = controller.write_raw
-    else:
-        method = controller.write
-    method(name=name, value=value, event=event, raw=raw)
-    print("Done.")
-
-
 def parse_options():
     parser = argparse.ArgumentParser(description="Send control messages to an "
             "attached OpenXC CAN translator", parents=[device_options()])
     parser.add_argument("command", type=str,
-            choices=['version', 'reset', 'write', 'writeraw'])
+            choices=['version', 'reset', 'write'])
     write_group = parser.add_mutually_exclusive_group()
     write_group.add_argument("--name", action="store", dest="write_name",
             help="name for message write request")
     write_group.add_argument("--id", action="store", dest="write_id",
             help="ID for raw message write request")
+    parser.add_argument("--bus", action="store", dest="write_bus",
+            help="bus number for raw message write request")
     parser.add_argument("--value", action="store", dest="write_value",
             help="optional value for message write request")
     parser.add_argument("--event", action="store", dest="write_event",
             help="optional event for message write request")
     parser.add_argument("--data", action="store", dest="write_data",
             help="data for raw message write request")
-    write_group.add_argument("-f", "--file", action="store",
+    write_group.add_argument("-f", "--write-input-file", action="store",
             dest="write_input_file",
-            help="path to a file with a list of message requests")
+            help="the path to a file with a list of raw or translated "
+                    "messages to write to the selected vehicle interface")
 
     return parser.parse_args()
 
@@ -104,27 +97,20 @@ def main():
     elif arguments.command == "reset":
         reset(controller)
     elif arguments.command.startswith("write"):
-        name = value = None
         if arguments.command == "write":
-            raw = False
             if arguments.write_name:
-                name = arguments.write_name
-                value = arguments.write_value
-                event = arguments.write_event
-        elif arguments.command == "writeraw":
-            raw = True
-            if arguments.write_id:
+                controller.write(name=arguments.write_name,
+                        value=arguments.write_value,
+                        event=arguments.write_event)
+            elif arguments.write_id:
                 if not arguments.write_data:
                     sys.exit("%s requires an id and data" % arguments.command)
-                name = arguments.write_id
-                value = arguments.write_data
-                event = None
-
-        if name:
-            write(controller, name, value, event, raw)
-        elif arguments.write_input_file:
-            write_file(controller, arguments.write_input_file, raw=raw)
-        else:
-            sys.exit("%s requires a name or filename" % arguments.command)
+                controller.write(bus=int(arguments.write_bus),
+                        id=arguments.write_id,
+                        data=arguments.write_data)
+            elif arguments.write_input_file:
+                write_file(controller, arguments.write_input_file)
+            else:
+                sys.exit("%s requires a signal name, message ID or filename" % arguments.command)
     else:
         print("Unrecognized command \"%s\"" % arguments.command)
